==> kibana-7.3.0-1-any.pkg.tar.xz: usr/share/kibana/src/legacy/core_plugins/kibana/public/visualize/embeddable/disabled_lab_embeddable.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DisabledLabEmbeddable = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _embeddable = require("ui/embeddable");

var _i18n = require("ui/i18n");

var _disabled_lab_visualization = require("./disabled_lab_visualization");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var DisabledLabEmbeddable =
/*#__PURE__*/
function (_Embeddable) {
  _inherits(DisabledLabEmbeddable, _Embeddable);

  function DisabledLabEmbeddable(title) {
    var _this;

    _classCallCheck(this, DisabledLabEmbeddable);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DisabledLabEmbeddable).call(this, {
      title: title
    }));

    _defineProperty(_assertThisInitialized(_this), "domNode", void 0);

    return _this;
  }

  _createClass(DisabledLabEmbeddable, [{
    key: "render",
    value: function render(domNode) {
      if (this.metadata.title) {
        this.domNode = domNode;

        _reactDom.default.render(_react.default.createElement(_i18n.I18nContext, null, _react.default.createElement(_disabled_lab_visualization.DisabledLabVisualization, {
          title: this.metadata.title
        })), domNode);
      }
    }
  }, {
    key: "destroy",
    value: function destroy() {
      if (this.domNode) {
        _reactDom.default.unmountComponentAtNode(this.domNode);
      }
    }
  }]);

  return DisabledLabEmbeddable;
}(_embeddable.Embeddable);

exports.DisabledLabEmbeddable = DisabledLabEmbeddable;

==> kibana-7.4.2-1-any.pkg.tar.xz: usr/share/kibana/src/legacy/core_plugins/kibana/public/visualize/embeddable/disabled_lab_embeddable.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DisabledLabEmbeddable = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _public = require("../../../../embeddable_api/public/np_ready/public");

var _disabled_lab_visualization = require("./disabled_lab_visualization");

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var DisabledLabEmbeddable =
/*#__PURE__*/
function (_Embeddable) {
  _inherits(DisabledLabEmbeddable, _Embeddable);

  function DisabledLabEmbeddable(title, initialInput) {
    var _this;

    _classCallCheck(this, DisabledLabEmbeddable);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DisabledLabEmbeddable).call(this, initialInput, {
      title: title
    }));
    _this.title = title;

    _defineProperty(_assertThisInitialized(_this), "domNode", void 0);

    _defineProperty(_assertThisInitialized(_this), "type", _constants.VISUALIZE_EMBEDDABLE_TYPE);

    return _this;
  }

  _createClass(DisabledLabEmbeddable, [{
    key: "reload",
    value: function reload() {}
  }, {
    key: "render",
    value: function render(domNode) {
      if (this.title) {
        this.domNode = domNode;

        _reactDom.default.render(_react.default.createElement(_disabled_lab_visualization.DisabledLabVisualization, {
          title: this.title
        }), domNode);
      }
    }
  }, {
    key: "destroy",
    value: function destroy() {
      if (this.domNode) {
        _reactDom.default.unmountComponentAtNode(this.domNode);
      }
    }
  }]);

  return DisabledLabEmbeddable;
}(_public.Embeddable);

exports.DisabledLabEmbeddable = DisabledLabEmbeddable;
